@@ -52,7 +52,8 @@ class DockerActions(Actions):
                                 self.arguments.log_dir,
                                 self.arguments.image,
                                 self.arguments.restart,
-                                self.arguments.privileged)
+                                self.arguments.privileged,
+                                self.arguments.update_image)
 
             master_ip = self.docker_cmd.docker_exec_in_daemon("hostname -i", return_output=True)
             self.env_add_conf({'master_ip': master_ip})
@@ -154,15 +155,13 @@ class DockerActions(Actions):
 
         self.docker_cmd.docker_exec_in_daemon('pkill jupyter')
         
-        arguments = " ".join(self.arguments.rest_args)
-        working_dir = self.env_conf['working_dir']
-        for arg in self.arguments.rest_args:
-            dir = working_dir + '/' + arg
-            if os.path.isdir(dir):
-                print(f"Opening jupyter server in `{dir}`")
-                break
+        cmd = 'notebook'
+        if len(self.arguments.rest_args) > 0:
+            if self.arguments.rest_args[0] == 'lab' or self.arguments.rest_args[0] == 'notebook':
+                cmd = ''
 
-        jupyter_cmd = "jupyter-notebook " + \
+        arguments = " ".join(self.arguments.rest_args)
+        jupyter_cmd = f"jupyter {cmd} " + \
                 arguments + " " + \
                 f"--ip={self.env_conf['master_ip']} " + \
                 "--allow-root " + \
@@ -233,7 +232,10 @@ class DockerActions(Actions):
 
     def env_remove(self, env_id=None):
         if self.docker_cmd.exists(self.env_conf['name']):
-            self.docker_cmd.docker_exec_in_daemon('rm -rf .COMPSs')
+            try:
+                self.docker_cmd.docker_exec_in_daemon('rm -rf .COMPSs')
+            except:
+                pass
             self.docker_cmd.docker_kill_compss()
         super().env_remove(eid=env_id)
 
