@@ -108,7 +108,11 @@ class LocalActions(Actions):
             working_dir = self.env_conf['working_dir']
 
         jupyter_args = self.arguments.rest_args
-        local_jupyter(working_dir, ' '.join(jupyter_args))
+        if jupyter_args[0] == 'lab':
+            cmd = 'lab'
+        else:
+            cmd = 'notebook'
+        local_jupyter(working_dir, cmd, ' '.join(jupyter_args))
 
     def exec(self):
         command = ' '.join(self.arguments.exec_cmd)
